---
layout: assignment
published: true

title: Benchmarking AI Ableism
revised: 3/23/2024

objective: Learn about benchmarking in AI 

---
# Overview

The goal of this assignment is to investigate ableism in a generative AI model. It will also give you a chance to learn about best practices for benchmarking 

## Learning Goals / Competencies
This homework will contribute to your competency grade on 
- Accessible document/presentation creation 

It may also contribute to your competencies on 
- Finding First Person Accounts of Accessibility Tech
- Familiarity with a range of accessibility technologies
- Image description

# Basic Requirements for Project

Your goal in this project is to create a set of benchmarks, and test them, on a generative AI platform of your choice. 

## Preparation
Two recent papers have conducted benchmarking tasks. You may find it valuable to read them. 

The first paper is a study of ableism in resume ranking titled ["Identifying and Improving Disability Bias in GAI-Based Resume Screening"](https://arxiv.org/abs/2402.01732). The primary method used was to ask GPT to rank two almost identical resumes, and then explain its ranking. Qualitative and quantatative analyses were conducted on the results.

The second paper is called ["'They only care to show us the wheelchair': disability representation in text-to-image AI models"](https://drive.google.com/file/d/1Fys0pKsAFqN9zY8LcxxL2lTUmn01xU73/view?usp=sharing). The authors developed a series of prompts that they provided to generate images from text, and then showed those images to disabled participants to gather qualitative responses to those images. 

# Details

To complete this assignment you will need to do the following (we hope to accomplish some of this in small groups in class)

## 0. Pick a  GAI and a task 
You will need to pick a domain in which to develop your benchmark. For example, the task could be generating images of disabled people, generating stories that include disabled characters, generating ALT text of images that have disabled people in them, and so on. Try to find a first person account of someone with a disability using the GAI for that task.

## 1. Search for known examples of human ableism in this domain
It is likely that GAI ableism will reproduce human ableism, which is likely documented somewhere. For example, there are articles about  [ableism visual representations of disabled people](https://mythcreants.com/blog/five-common-harmful-representations-of-disability/); [ableist tropes in fiction](https://bookriot.com/ableist-tropes-in-fiction/) and [problematic language in descirptions of disabled people](https://ncdj.org/style-guide/). 

## 2. Develop prompts that are likely to elicit ableism 
Based on one or more of the resources and if relevant your own experiences, develop a series of prompts that can be used to test ableism in GAI 

## 3. Collect data on these prompts and analyze it 
This is somewhat open ended. You could compare the same prompts with and without disability, or just do a bottom up coding of the results of the prompting for example

## 4. Reflect on what you learned

Write a 1 page reflection telling us about
- What the GAI you chose does.
- What task you used it for, and what are the strengths and weaknesses of the GAI for that task from the perspective of a disabled person (ideally informed by a first person account)
- What background research you did on possible sources of ableism
- What prompts you used 
- What you found
- An appendix with example data you generated
- An appendix with a list of the [competencies](index.html#competencies) you wish to be assessed on, if any, beyond the required Accessible Document/Presentation creation. For example, if you include an image, should should describe it and we will assess Image Descriptions. If you find a first person account, you could include a link to the first person account and also meet the requirements for familiar with a range of AT by adding an appendix describing the range of users and strengths and weaknesses of the AT. 

# Hand in

Turn your writeup in on [Canvas]({{site.canvas}})
