---
layout: assignment
published: true

title: A11yhood  Analysis
description: Analyze an article using our a11yhood framework
revised: October 27, 2024
---
* TOC
{:toc}

# Overview 

The goal of this homework is to apply the A11yhood framework to analyzing a policiy, practice, technology, etc based on an article.

##  Competencies
This homework may contribute to 
- Your competency grade on Plain Language Writing
- Your competency grade on Disability Justice Analysis
- Your competency grade on Positive Disability Principals
- Your competency grade on Accessible Document Creation
- Other competencies you choose, if relevant (such as image description, if you include an image)

## Length & Difficulty
Students in the past have reported that this assignment takes an median of 4 hours (mode=3). However, in our experience many students have to make multiple attempts to fully meet the competency for disability justice. It is recommended to carefully read about the 10 principals and ask questions if you are having trouble understanding which one might apply. 
Some things students have told us about this assignment:
- "Writing well in Plain language is harder than I thought."
- it is sometimes hard to identify a remedy. Again, reach out if you need help here.

# Turnin
1. Complete the assignment as described below. 
2. [Submit]({{site.submit}}) your writeup based on this [template outline](disabilityjustice-template.html).

# Details

To complete this assignment, you will need to do  the following

## 0. Select an article to focus on.
You may use one of the articles we have provided (see below) or find one of your own (requires instructor approval). The article should discuss a practice, policy, or technology that impacts disabled people. 

{% details Possible readings %}
- [masking and disability](https://www.teenvogue.com/story/mask-bans-disabled-people-protest) "There are days when I am overwhelmed with grief and rage at the regressive attitudes toward public health and disabled people. In my opinion, the ableist, fascistic, and eugenic nature of proposed mask bans under consideration in New York City and Los Angeles is bleak." -- By [Alice Wong, recent Macarthur genius award winner](https://www.macfound.org/fellows/class-of-2024/alice-wong). 
- [the school to prison pipeline](https://ncd.gov/publications/2015/06182015/) "Studies show that up to 85 percent of youth in juvenile detention facilities have disabilities that make them eligible for special education services, yet only 37 percent receive these services while in school.  A disproportionate percentage of these detained youth are youth of color.  These statistics should lead to the conclusion that many disabled youth in the juvenile justice and criminal justice systems are deprived of an appropriate education that could have changed their School-to-Prison Pipeline trajectory."
- [policing and disability](https://www.theatlantic.com/health/archive/2014/05/misunderstanding-disability-leads-to-police-violence/361786/) and [policing and autism](https://chicagoreader.com/news-politics/black-autistic-and-killed-by-police/) "People with an autism spectrum disorder are seven times more likely to encounter police than “neurotypical” individuals, or those without developmental disabilities, according to autism experts. Depending on the severity of their disorder, people on the autism spectrum can react inappropriately to police and have trouble following commands."
- [disability in  prison](http://avidprisonproject.org/Making-Hard-Time-Harder/) "A prison sentence shouldn't be harder, it shouldn't be longer, and conditions of confinement shouldn't be harsher simply because of a disability."
- [disability and sex work](http://titsandsass.com/having-the-option-alissa-afonina-on-her-case-and-being-a-disabled-sex-worker/) and [disability and sexuality](https://www.theatlantic.com/health/archive/2015/03/sex-and-disability/386866/) "When you are disabled, the two things people think you can’t do are fight and have sex. So I’ve got a black belt and I’m really good at shagging."
- [the right to be rescued](https://rootedinrights.org/video/therighttoberescued/) and [disability and disaster response](https://www.un.org/development/desa/disabilities/issues/disability-inclusive-disaster-risk-reduction-and-emergency-situations.html) "persons with disabilities are more likely to be left behind or abandoned during evacuation in disasters and conflicts due to a lack of preparation and planning, as well as inaccessible facilities and services and transportation systems. Most shelters and refugee camps are not accessible and people with disabilities are many times even turned away from shelters and refugees camps due to a perception that they need “complex medical” services. Disruption to physical, social, economic, and environmental networks and support systems affect persons with disabilities much more than the general population. There is also a potential for discrimination on the basis of disability when resources are scarce. Furthermore, the needs of persons with disabilities continue to be excluded over the more long-term recovery and reconstruction efforts, thus missing another opportunity to ensure that cities are accessible and inclusively resilient to future disasters."
- [algorithmic healthcare](https://www.theverge.com/2018/3/21/17144260/healthcare-medicaid-algorithm-arkansas-cerebral-palsy) "Dobbs’ situation hadn’t improved, but an invisible change had occurred. When the assessor entered Dobbs’ information into the computer, it ran through an algorithm that the state had recently approved, determining how many hours of help she would receive.... The change left Dobbs in a situation she never thought she would be in, as the program she’d relied on for years fell out from below her."
- [access versus cures](https://www.youtube.com/watch?v=7LHNwzLa-88) "is medicine about quality of life or is it about social control?"
- [intimacy](https://leavingevidence.wordpress.com/2017/08/06/forced-intimacy-an-ableist-norm/) "Forced Intimacy” is a term I have been using for years to refer to the common, daily experience of disabled people being expected to share personal parts of ourselves to survive in an ableist world. This often takes the form of being expected to share (very) personal information with able bodied people to get basic access, but it also includes forced physical intimacy, especially for those of us who need physical help that often requires touching of our bodies."
- Access overlays, specifically [accessibe](https://www.vice.com/en/article/m7az74/people-with-disabilities-say-this-ai-tool-is-making-the-web-worse-for-them) "They’re actively marketing ‘Hey, don’t worry about it, don’t worry about learning about accessibility—use our automated tool. And not only does the automated tool not fix things, but it gives companies a reason not to educate their coders,” Chancey Fleet, president of the National Federation of the Blind’s assistive technology trainers division, told Motherboard. (Optional  [related article](https://www.linkedin.com/pulse/lies-damned-overlays-widgets-timothy-springer/))
- [are airlines hearing wheelchair users' protests?](https://newmobility.com/taking-on-the-unfriendly-skies/) "'Every time I get on an airplane, I’m afraid,' he says. 'I figure I’m gonna get hurt. I’m gonna get COVID. And my chair is gonna get broken.' For him, the choice was clear."
- [disability doulas](https://19thnews.org/2023/07/disability-doulas-support-newly-disabled-people/) "The community care practice, pioneered by queer women of color, reorients newly disabled people to a different life – a necessity that has grown during the pandemic era."
- [disabled fashion program](https://www.teenvogue.com/story/parsons-new-disabled-fashion-student-program-aims-to-create-change-in-the-industry?utm_source=The+19th&utm_campaign=197c9f8fd2-19th-newsletters-daily-0703&utm_medium=email&utm_term=0_a35c3279be-197c9f8fd2-359903616) "Parsons is hoping to change the fashion industry's failure to not only recognize disabled people as consumers and wearers but also as creatives with its new initiative, which is set to launch this fall and will support three fashion students to start."
- [F for recording class](https://www.insidehighered.com/news/faculty-issues/academic-freedom/2024/07/10/fs-recording-class-even-students-disabilities?utm_source=Inside+Higher+Ed&utm_campaign=5fbf144c45-DNU_2021_COPY_02&utm_medium=email&utm_term=0_1fcbc04421-5fbf144c45-197755297&mc_cid=5fbf144c45) "A UCLA professor whose classroom hosts contentious debates says she’ll fail any student who records. She says it’s a matter of academic freedom. But does federal law allow it?"
- [the "Deaf Tax"](https://themindhears.org/2024/07/16/the-deaf-tax-and-speaking-for-others/) "It seems unfair for us to be charged the full registration rate when we do not have access to the conference."
{% enddetails %}

## 1. Read and summarize article on the topic you have selected. 
Read your article and summarize it. Your summary should be one paragraph long (200-300 words).

## 2. Analyze it from the perspective of the Positive Disability Principals. 
Is the practice, policy, or technology:

- Ableist?
- Accessible in part or as a whole?
- Disability led? 
- Being used to give control and improve agency for people with disabilities
- Addressing the whole community (intersectionality, multiple disabled people, multiply disabled people)

## 3. Select and write about 3 Disability Justice Principles 

Select at least 3 of the [10 principles of disability justice](https://static1.squarespace.com/static/5bed3674f8370ad8c02efd9a/t/5f1f0783916d8a179c46126d/1595869064521/10_Principles_of_DJ-2ndEd.pdf). Please note that the principals of disability justice are political in nature -- that is an important reason we let you select among them. Whether you agree with them or not, we are asking you to demonstrate your understanding what the disability community has put forth in defining these principals. 

For each principle, 
- Name and define it in your own words
- Write 1-2 paragraphs (~200-300 words) explaining how  the service or technology described in the article you picked addresses, or fails to address, that principal. 
- Explain how it could do a better job of embodying that principle

## 4. Learn about plain language and write a second summary in plain language
Read about [plain language writing for accessibility](https://www.forbes.com/sites/andrewpulrang/2020/10/22/plain-language-writing---an-essential-part-of-accessibility/?sh=4afd8af77935) and [plain language guidelines](https://www.med.unc.edu/healthsciences/clds/wp-content/uploads/sites/859/2021/06/Minimized-Text-Complexity-Guidelines-version-2.03.2021.pdf) and check out examples at the [plain truth project](https://www.plaintruthproject.org).

Read the expectations for the plain language competency in the [canvas outcomes]({{site.canvas}}/outcomes). 

Then decide which plain language guidelines you will file **new: (from those listed in the rubric)** and list them. Finally, use the guidelines to simplify the text from your 200-300 word summary. Include this second version of your 200-300 word summary in your hand in. 

Some tools that students have found helpful in the past for plain language writing include ChatGPT, the [Hemingway editor](https://hemingwayapp.com/), and the [readability scoring system](https://readabilityformulas.com/readability-scoring-system.php) which has visualizations of sentence and word level stats after you run it. Any of these tools are only somewhat useful, you have to use your own judgement as well to be successful with them as they frequently make mistakes in judging what is complicated, and tools like ChatGPT may also introduce factual errors when changing your text content. 

**Note:** This is the only thing in this assignment that needs to be in plain language. 

