---
layout: assignment
published: draft

title: Final Project Proposal
revised: March 23, 2024

description: Propose a project to make the world slightly more accessible

---
* TOC 
{:toc}

# Overview 

The goal of your final project is to build an accessibility technology or make an existing technology more accessible. In this phase of the final project, you will propose a specific project idea that you come up with.

{% details Final Project Examples from past Quals Courses %} 
Some examples of what people have done in the past include:
**UPDATE**
{% enddetails %}


{% details Final Project Examples From Past Graduate Accessibility Courses %}
Some examples of what people have done in the past:
**UPDATE**
<!-- - [Making a light mode for zoom](https://students.washington.edu/sgbowen8/light-mode/) -->
- [Creating a plugin for word to prompt for better alt text](https://thenorthwes.github.io/improved-word-alt-text/)
- [Make Arduino programming more accessible](https://uwcse-nsds.github.io/arduino-a11y/)
- Make a system to help someone with motor impairments create [macros for fixing typos](https://katyp.github.io/input_macros)
- Improving [coding accessibility for BLV people in VS Code](https://kburtram.github.io/CodeTalk/)
- Developing a [plain language checker](https://yichiang.github.io/plain-language-checker/#/)
- Improving [chart accessibility](https://accessiplot.readthedocs.io/en/latest/)
- Improving the accessibility of a [VS Code plugin for code tours](https://github.com/cclaridad/codetour)
- Creating [tactile schematics](https://www.hackster.io/monica/creating-tactile-schematics-using-fritzing-5b47f8) for circuits
- Making [markdown accessible](https://github.com/jaedong98/accessibility4md)
- Addressing [open issues](https://github.com/odilia-app/odilia/pulls?q=is%3Apr+is%3Aclosed+author%3Asamtay) for a free and open source screen reader, [Odilia](https://github.com/odilia-app/)
- **Qbit: An Accessible Tangible User Interface for Window Management and Multitasking**: Screen reader users who are blind use built-in mechanisms (e.g. alt+tab) to switch between windows. This requires them to remember the ordering of windows in these tab
switchers and linearizes the switching process. Sighted computer users, on the other hand, use a variety of strategies like positioning windows and tabs within and across screens. We address this gap through an exploratory Tangible User Interface (TUI) -- a physical cube -- and report results from an exploratory pilot with one participant. Our preliminary findings show that rotating the cube is an intuitive way to navigate between windows and tabs, the cube’s verbal feedback is helpful while switching windows, and user can distinguish different sides easily due to the textures on the cube.
- **Knitting4All: Fabricating Solutions to Knitting Accessibility Problems**: We performed one (soon to be more) case study
with a participant, pseudonym Magnolia, with a traumatic brain injury (TBI), which causes her tremors, pain in her hands, loss of movement in her right (dominant) hand, double vision, and short term memory loss. Using a combination of semi structured interviews and contextual inquiry, we met with our participant to get a sense of how they knit today, the issues they face, and their goals for what they would like to knit. Following, we utilized participatory design, dubbing our participant as the expert, and
worked closely with the participant to create prototypes via 3D printing and software programming to help her knit more complex patterns with more comfort (now published as part of ["Stitching Together the Experiences of Disabled Knitters"](https://dl.acm.org/doi/10.1145/3411764.3445521))
- **[Dis]placed: navigating third places and chronic illness**: People experiencing chronic illness often are excluded from
third places for relaxing and socializing outside of the workplace and home. Designs of public places often neglect important characteristics like: frequent seating, temperature control, and accessible restrooms. However, public places also provide healing elements like relaxation, socialization, and views of nature. Because of the lack of proper design of third places, people with chronic illness find it challenging to find third places that fit their accessible and therapeutic needs and preferences. This project explored whether an information service could be helpful for people navigating the experience of place and chronic illness, by showing which places have certain qualities (now published as part of ["Navigating Illness, Finding Place: Enhancing the Experience of Place for People Living with Chronic Illness"](https://dl.acm.org/doi/10.1145/3460112.3471955)
{% enddetails %}

We have solicited project ideas from faculty, researchers and community members. They will be made available on the [class discussion board]({{site.discussion}})

## Learning Goals / Competencies
Required Competencies for this homework:

- Accessible Document Creation
- Disability Model Analysis
- Application of Positive Disability Principals to Research
- Finding First Person Accounts of Accessibility Tech

Other competencies, such as image description, depend on what you have in your proposal.

## Length & Difficulty
We do not have details on how long this single piece of the final project usually takes students. However, overall students report a median of 7.5 hours per week plus meetings during the four weeks of the project. Some things students commented on regarding the project include:
- "I appreciate the open-endedness of this project. It gives a good opportunity to apply what we have learned, combined with the knowledge we have brought to this course."
- "I like how open ended the project is, and it made for a really interesting last session with a wide variety of presentations."
- "Learned a lot through the project"

# Details
To complete this assignment, you will need to do the following

## 0. Brainstorm an Idea
 In choosing this project, you may want to draw from personal expertise, literature, or user data should you have access to it. Your idea should have the following components. 
 - Implementation component: This project should require the creation of novel technology or resources involving programming. 
 - Validation component: Your project also must include a validation component (some way of measuring how well it works). This typically involves developing a set of examples and metrics for success, and assessing how well the technology performs on them. 
 
*Note on disability involvement in this project* It is not feasible to do a full iterative design cycle in this project (and not necessarily an ethical use of the time of people with disabilities). However if you want to include data from interviewing, or testing with, people with disabilities, that is permissible. That said, your project should not unduly burden the disability community. Some projects may allow for direct collaboration with or feedback from people with disabilities, others may not. Please reach out to us for guidance on this if you intend to work with disabled participants. 
 
## 1. Develop an Argument for The Idea

Your idea should be 
- *Promising:* It should offer novel research insights or technology that will help to advance both our field, and the needs of people with disabilities
- *Informed by a [First Person Account](index.html#3-finding-first-person-accounts-of-accessibility-tech")
- Embody *Positive Disability Principles:* We understand that you cannot necessarily address all of the positive disability principles that we discuss in class, but at the very least you should be able to argue for principles 1 and 4: (1) It is not ableist (4) It furthers disabled agency and control. Ideally, you will also be able to address at least one more principle of the five [specified in the competency](index.html#4-application-of-positive-disability-principals-to-research). 
- Embody *Disability Theory:* You should consider what [disability theories/principles](index.html#1-disability-model-analysis) are useful in guiding your work. 
- Feasible in the time available during the quarter. 

## 2. Write About Your Proposal

Your write up should include the following information
- *Promise:* 
   - What new knowledge or capabilities does this project enable?
   - Why is this challenging today? What is already known about this, and what is not known? You should discuss related literature and/or products in answering this question. 
- What [First Person Account](index.html#3-finding-first-person-accounts-of-accessibility-tech") are you drawing from? What data do you have about the disability need for this? You must have one of the following
   - An existing ongoing project involving interviews or other engagements with people with disabilities that you can refer to
   - Find an existing interview paper or ethnography/auto-ethnography on the topic
   - Find an  online content creator who provides a first person account of the need for this project
- How does this project embody [Positive Disability Principles](index.html#4-application-of-positive-disability-principals-to-research):?
   - List the principals you are addressing (you must include at least 1 and 4) and explain how they are embodied in your work.
- What [disability theories/principles](index.html#1-disability-model-analysis) are guiding your work?
   - List the theories you are drawing from and explain how they are guiding your work. 
- Feasible in the time available during the quarter. 
   -  What do you plan to accomplish by each of the two intermediate project milestones (week 7 and 10), and by the end of the quarter (week 12)?  
   -  What will you *omit* in order to make the project feasible? In other words, how will you scope this project to fit within the quarter? Given the number of weeks available (7), be careful not to over commit.  

# Turnin 
Submit your write up on Canvas. 


