---
layout: assignment
published: true

title: Accessibility Implementation 
description: Apply accessibility principals to a thing
revised: October 22, 2024

---

* TOC
{:toc}

# Overview
The goal of this homework is to make something more accessible. Specifically, you should create a *more accessible version* of a thing (website, visualization, user interface, AR/VR, etc) that you've already made.

## Learning Goals / Competencies
This homework will contribute to your competency grade on
- Accessible Document Creation
- Familiarity with a Range of Accessibility Technologies
- Image Description
- Web/App Accessibility Rules
- Accessible Presenting

It may contribute to other competencies depending on how you approach it. 

# Turnin

[Submit]({{site.submit}}) your writeup following the [template](technology-implementation-template.html)

# Details
To complete this assignment, please do the following:

## 1. Select a specific interface or web app that you will make more accessible
You should identify a technology you have implemented *for general use* (i.e. not an accessibility technology). Ideally this should be an interactive technology (some kind of user interface, app, etc).  If you have no such thing, you can ask to approve using a website or other static content that you have generated as an alternative. 

{% details Possible examples (this list is still under construction) %}
- A class assignment that has an interface (web, mobile or other). If you've built a mobile app for 340, built a website for 154, or taken 331 (such as the campus map website) or 442 (if you made a website) these are all things you could use.
- A web or mobile app you built yourself
- A profile of yourself on linked in, tiktok, or any other site where you've posted content.
- Your personal website (even if it's hosted somewhere else like wordpress)
- An interface wrapped around some machine learning program
- An educational game for young children 
- Tools for learning programming 
- A visualization
- A password or CAPTCHA interface
- VR/AR: A game or game control interface. 
{% enddetails %}

Also be clear about what task you want to accomplish. 

## 2. Select an accessibility technology and test your app with it

Record the following information in your [reflection](technology-implementation-template.html)
- What website/application and task you were testing (include a screen shot)
- Which accessibility technology did you use and which disability you focused on
- Test out your app with that accessibility aid and identify any problems with completing that task. Fill out at least 2 UARs describing different problems you found and summarize your findings
- To satisfy your AT Familiarity competency, you need to use an AT to find and demonstrate the problem. Do not use WAVE or other automated tools. 

## 3. Fix the problem 
Once you have identified problems, it is time to fix them. The expectations here will depend partly on the details of the task you select (which must be instructor approved) but it needs to include at least two different areas of POUR (i.e. address issues with both percievability and operability) or otherwise demonstrate that you have not done something overly simple.

- Add a description of what you fixed to your writeup
- Add a paragraph describing something you learned from this assignment to your writeup

## 4. Present it to us
You will be presenting your work to us on Friday 10/25 during regular class time. Your presentation will need to demonstrate the problems you found and the fix you created. This should include a "before & after" style presentation, showing the website/app you tested, what was wrong with it to begin with, how you fixed it, and how it looks/works after the fix.

- You will each have 3 minutes to present and then time to take one question. 
- You can either do a live demo of your fix or show a recording of the fixed behavior during your live presentation. 
- Class on that day will be fully virtual, and we'll assign each of you to a Zoom meeting. You’ll be able to show your own screen and present your slide decks from your own device. 
- Upload your slide deck to Canvas by 10/24 for presentation accessibility (24 hours in advance)
- Please turn on video when presenting (unless this poses an access issue for you)!



